==> eole-client_2.4.0-7.tar.gz: eole-client-7/sources/all/test_code.py <==
# _*_ coding: iso-8859-1 _*_
#!/usr/bin/env python

import os, glob
import sys, time, commands
import subprocess

class toto:
    def __init__(self):
        self.f = os.path.join(os.getcwd(), 'log_test_code.log')
        file(self.f, 'w').write('%s\n'%time.ctime())

    def write(self, msg):
        fh = file(self.f, 'a')
        fh.write(msg)
        fh.close()

sys.stdout = toto()
sys.stderr = sys.stdout

def execute(cmd):
    p = subprocess.Popen(args=cmd.split(), stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=False)
    code = p.wait()
    msg = p.stdout.read()
    msg = 'EXECUTE : '+msg.strip()
    return code, msg

def test_flakes(i):
    cmd = 'pyflakes.bat %s'%i
#    print cmd
    print execute(cmd)[1]
    print

def test_checker(i):
    cmd = 'pychecker.bat --limit 80 %s'%i
#    print cmd
    print execute(cmd)[1]
    print

def test_pylint(i):
    cmd = 'pylint.bat -r n --disable-msg-cat=C %s'%i
#    print cmd
    print execute(cmd)[1]
    print


def lance(fichs):
##    fichs.sort()
    print fichs

    for i in fichs:
        if not i.endswith('.py'): continue
        print "#"*(26+len(i))
        print "#            %s            #"%i
        print "#"*(26+len(i))
        print
        print "#######  PYFLAKES  #######"
        test_flakes(i)
        print "#######  PYCHECKER  #######"
        test_checker(i)
        # print "#######  PYLINT  #######"
        # test_pylint(i)

    print 'Termin'
    print

fichs = [
'utilisateur.py',
'confservscribe.py',
'setup-servscribe.py',
]

lance(fichs)
print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
print '       changement de dossier "eole" '
print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"

os.chdir('eole')


fichs=(
# 'iphelp.py',
'background.py',
'logon_service.py',
'pbgest.py',
'replace_win_vars.py',
# 'versioneole.py',
##'pbutils.py',
##'versioneole.py',
##'messagebox.py',
##'replace_win_vars.py',
##'ini.py',
##'wxPbloc_reseau.py.s',
##'params.py',
##'download.py',
##'iphelper_open_ports.py',
##'iphelper_extended_tcptable.py',
##'iphelp.py',
##'perms.py',
##'dict4ini.py',
##'process.py',
##'fonctions.py',
##'test_copyable',
##'wusers.py',
##'wxPobservation.py',
##'wxPdevoir.py.sav',
##'gest_devoir.py',
##'vnc.py',
##'wxPdevoir.py',
##'winfw.py',
##'pbserverclient.py',
##'wsessions.py',
##'servscribe_class.py',
##'wxPbloc_reseau.py',
##'lecteurs.py',
##'servscribe_pbserver.py',
)

lance(fichs)

print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
print '       changement de dossier "backend" '
print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"

# os.chdir('../../../backend')


# fichs=(
# 'autorisations.py',
# 'gest_sessions.py',
# 'cron_stop_station.py',
# 'ConfigParserOnlyEqualSeparator.py',
# 'machines.py',
# 'log.py',
# 'fonctions.py',
# 'esu.py',
# 'scripts.py',
# 'connexions.py',
# 'dict4ini.py',
# 'vnc.py',
# 'ldap_utils.py',
# 'pbutils.py',
# 'manage_stations.py',
# 'devoirs.py',
# 'cliscribe.py',
# 'controle_vnc_serveur.py',
# 'blocage.py',
# )

# lance(fichs)

==> eole-client_2.5.2-7.tar.gz: eole-client-7/sources/all/test_code.py <==
# _*_ coding: iso-8859-1 _*_
#!/usr/bin/env python

import os, glob
import sys, time, commands
import subprocess

class toto:
    def __init__(self):
        self.f = os.path.join(os.getcwd(), 'log_test_code.log')
        file(self.f, 'w').write('%s\n'%time.ctime())

    def write(self, msg):
        fh = file(self.f, 'a')
        fh.write(msg)
        fh.close()

sys.stdout = toto()
sys.stderr = sys.stdout

def execute(cmd):
    p = subprocess.Popen(args=cmd.split(), stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=False)
    code = p.wait()
    msg = p.stdout.read()
    msg = 'EXECUTE : '+msg.strip()
    return code, msg

def test_flakes(i):
    cmd = 'pyflakes.bat %s'%i
#    print cmd
    print execute(cmd)[1]
    print

def test_checker(i):
    cmd = 'pychecker.bat --limit 80 %s'%i
#    print cmd
    print execute(cmd)[1]
    print

def test_pylint(i):
    cmd = 'pylint.bat -r n --disable-msg-cat=C %s'%i
#    print cmd
    print execute(cmd)[1]
    print


def lance(fichs):
##    fichs.sort()
    print fichs

    for i in fichs:
        if not i.endswith('.py'): continue
        print "#"*(26+len(i))
        print "#            %s            #"%i
        print "#"*(26+len(i))
        print
        print "#######  PYFLAKES  #######"
        test_flakes(i)
        print "#######  PYCHECKER  #######"
        test_checker(i)
        # print "#######  PYLINT  #######"
        # test_pylint(i)

    print 'Termin'
    print

fichs = [
'utilisateur.py',
'servscribe_class.py',
'servscribe.py',
]

lance(fichs)
print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
print '       changement de dossier "eole" '
print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"

os.chdir('eole')


fichs=(
'iphelp.py',
# 'background.py',
'logon_user.py',
# 'logon_service.py',
# 'pbgest.py',
# 'replace_win_vars.py',
'versioneole.py',
#'pbutils.py',
#'versioneole.py',
'messagebox.py',
#'replace_win_vars.py',
'ini.py',
#'wxPbloc_reseau.py.s',
#'params.py',
#'download.py',
# 'iphelper_open_ports.py',
#'iphelper_extended_tcptable.py',
# 'iphelp.py',
##'perms.py',
# 'dict4ini.py',
#'process.py',
#'fonctions.py',
#'test_copyable',
# 'wusers.py',
#'wxPobservation.py',
#'wxPdevoir.py.sav',
#'gest_devoir.py',
'vnc.py',
'vncuser.py',
#'wxPdevoir.py',
##'winfw.py',
#'pbserverclient.py',
# 'wsessions.py',
# 'servscribe_class.py',
#'wxPbloc_reseau.py',
#'lecteurs.py',
#'servscribe_pbserver.py',
)

lance(fichs)

print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
print '       changement de dossier "backend" '
print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"

# os.chdir('../../../backend')


# fichs=(
# 'autorisations.py',
# 'gest_sessions.py',
# 'cron_stop_station.py',
# 'ConfigParserOnlyEqualSeparator.py',
# 'machines.py',
# 'log.py',
# 'fonctions.py',
# 'esu.py',
# 'scripts.py',
# 'connexions.py',
# 'dict4ini.py',
# 'vnc.py',
# 'ldap_utils.py',
# 'pbutils.py',
# 'manage_stations.py',
# 'devoirs.py',
# 'cliscribe.py',
# 'controle_vnc_serveur.py',
# 'blocage.py',
# )

# lance(fichs)
